0.4.0
=====
  - Make compatible with Django 1.9.

0.3.0
=====

  - Splitted the django-sampledatahelper and the sampledata library

0.2.1
=====

  - Fixed problem with data files to include in the package.

0.2.0
=====

  - Adding sampledatafiller command to fill models from settings configuration.
  - Adding ModelDataHelper to fill models automatically.
  - Adding new generators:
    - IPv4
    - IPv6
    - mac address
    - hex_chars
    - path
    - time
  - Adding more unit testing.

0.1.0
=====

  - Adding unit testing
  - Refactor the code
  - Some API changes
  - Python 3 compatibility
  - Adding SAMPLEDATAHELER_SEED setting variable
  - Create sphinx documentation (not finished)

0.0.3
=====

  - Added char, chars, url and choices_key methods

0.0.2
=====

  - Improved the README.rst
  - Removed the PIL hard dependency
  - Some minor fixes

0.0.1
=====

  - Initial version
